( cd usr/lib ; rm -rf libgtkgl-2.0.so )
( cd usr/lib ; ln -sf libgtkgl-2.0.so.1.0.0 libgtkgl-2.0.so )
( cd usr/lib ; rm -rf libgtkgl-2.0.so.1 )
( cd usr/lib ; ln -sf libgtkgl-2.0.so.1.0.0 libgtkgl-2.0.so.1 )
